# Helpers
Contains some useful helper functions for ML. It is now available in cli operatable command for ease access.

# Installation

Install directly through pip using the command below,
```
pip install helpers-ai
```
or from source file, first clone the git repository using the below code,

```
git clone https://github.com/code63ReaPer/helpers-ai.git
```
then install the package through pip using the command below,
```
cd helpers-ai
pip install .
```